@@ -1,4 +1,4 @@
-import gaurabda.GCMath as GCMath
+from . import GCMath as GCMath
 
 def GetRasi(SunLongitude,Ayanamsa):
 	return int(GCMath.Floor(GCMath.putIn360(SunLongitude - Ayanamsa)/30.0))
