@@ -3,8 +3,10 @@ from .TAppDay import TAppDay
 from .TCoreEvents import TCoreEvents
 from .TMasaList import TMasaList
 from .TToday import TToday
-from .GCGregorianDate import GCGregorianDate,Today
+from .GCGregorianDate import GCGregorianDate,Today, CalculateJulianDay
 from .GCLocation import GCLocation
 from .GCLocationList import FindLocation,GetLocationsForCountry
 from .GCCountry import GetCountries
 from .GCTimeZone import GetTimeZones
+from .GCEarthData import EARTHDATA
+from .GCEventList import SetFastingSchema
